@@ -307,6 +307,7 @@ static NSString *kUsingTableViewToShowData = @"UsingTableViewToShowData";
                 }
                 _reorderLayout = [[LXReorderableCollectionViewFlowLayout alloc] init];
                 [self.collectionView setCollectionViewLayout:_reorderLayout animated:NO];
+                _libraryMode = VLCLibraryModeFolder;
             }
         }
         @synchronized(self) {
@@ -573,6 +574,19 @@ static NSString *kUsingTableViewToShowData = @"UsingTableViewToShowData";
     } else {
         [self.collectionView reloadData];
         [self updateActionBarButtonItemStateWithSelectedIndexPaths:[self.collectionView indexPathsForSelectedItems]];
+        if (_libraryMode == VLCLibraryModeAllFiles) {
+            if (self.collectionView.collectionViewLayout != _folderLayout) {
+                for (UIGestureRecognizer *recognizer in _collectionView.gestureRecognizers) {
+                    if (recognizer != _folderLayout.panGestureRecognizer ||
+                        recognizer != _folderLayout.longPressGestureRecognizer ||
+                        recognizer != _longPressGestureRecognizer)
+                        [self.collectionView removeGestureRecognizer:recognizer];
+                }
+
+                [self.collectionView setCollectionViewLayout:_folderLayout animated:NO];
+                [self.collectionView addGestureRecognizer:_longPressGestureRecognizer];
+            }
+        }
     }
 
     [self _displayEmptyLibraryViewIfNeeded];
@@ -1007,16 +1021,9 @@ static NSString *kUsingTableViewToShowData = @"UsingTableViewToShowData";
 
         if ([item isKindOfClass:[MLFile class]]) {
             MLFile *file = (MLFile *)item;
-            MLLabel *folder = [file.labels anyObject];
             [self rearrangeFolderTrackNumbersForRemovedItem:file];
             file.labels = nil;
             file.folderTrackNumber = nil;
-
-            if ([folder.files count] == 0) {
-                [self removeMediaObject:folder updateDatabase:YES];
-                [self setEditing:NO];
-                [self backToAllItems:nil];
-            }
         }
         @synchronized(self) {
             [_foundMedia removeObject:item];
@@ -1252,7 +1259,7 @@ static NSString *kUsingTableViewToShowData = @"UsingTableViewToShowData";
     NSMutableArray *toolbarItems = [self.toolbarItems mutableCopy];
     toolbarItems[2] = createFolderItem;
     self.toolbarItems = toolbarItems;
-    [self setLibraryMode:_libraryMode];
+    [self setLibraryMode:_previousLibraryMode];
     [self updateViewContents];
 }
 
@@ -1493,6 +1500,12 @@ static NSString *kUsingTableViewToShowData = @"UsingTableViewToShowData";
 {
     _libraryMode = mode;
     [self updateViewContents];
+
+    if (mode == VLCLibraryModeAllAlbums ||
+        mode == VLCLibraryModeAllSeries ||
+        mode == VLCLibraryModeAllFiles) {
+        _previousLibraryMode = mode;
+    }
 }
 
 #pragma mark - autorotation
